@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -77,7 +77,7 @@ def classify_hybrid_vsearch_sklearn(ctx,
                                     min_consensus=0.51,
                                     maxhits='all',
                                     maxrejects='all',
-                                    reads_per_batch=0,
+                                    reads_per_batch='auto',
                                     confidence=0.7,
                                     read_orientation='auto',
                                     threads=1,
